@@ -1,18 +1,16 @@
 ## init_freq.R | riskyr
-## 2018 02 08
-## -----------------------------------------------
+## 2018 12 10
 ## Define and initialize ALL frequencies
 ## -----------------------------------------------
 
-## -----------------------------------------------
-## Table of current terminology:
+## Table of current terminology: -----------------
 
-# Probabilities (10):               Frequencies (11):
+# Probabilities (13+):              Frequencies (11):
 # -------------------               ------------------
 # (A) by condition:
 
 # non-conditional:                          N
-# prev*                           cond.true | cond.false (columns)
+# prev*                           cond_true | cond_false (columns)
 
 # conditional:
 # sens* = hit rate = TPR                hi* = TP
@@ -26,8 +24,8 @@
 # (B) by decision:                 Combined frequencies:
 
 # non-conditional:
-# ppod = proportion of dec.pos     dec.pos | dec.neg (rows)
-#                                  dec.cor | dec.err (diagonal)
+# ppod = proportion of dec_pos     dec_pos | dec_neg (rows)
+#                                  dec_cor | dec_err (diagonal)
 
 # conditional:
 # PPV = precision
@@ -35,26 +33,23 @@
 # FOR = false omission rate
 # NPV = neg. pred. value
 
+# (C) by accuracy/correspondence of decision to condition (see accu):
+
+# acc  = overall accuracy (probability/proportion correct decision)
+# p_acc_hi = p(hi|acc)  # aka. acc-hi  "p(hi | dec_cor)"
+# p_err_fa = p(fa|err)  # aka. err-fa  "p(fa | dec_err)"
+
+# Other measures of accuracy (in accu):
+# wacc = weighted accuracy
+# mcc  = Matthews correlation coefficient
+# f1s  = harmonic mean of PPV and sens
+
+# err = error rate = (1 - acc)
 
 
-## -----------------------------------------------
-## Data flow: Two basic directions:
+## (A) BASIC frequencies: ----------
 
-## (1) Probabilities ==> frequencies:
-##     Bayesian: based on 3 essential probabilities:
-##   - given:   prev;  sens, spec
-##   - derived: all other values
-
-## (2) Frequencies ==> probabilities:
-##     Frequentist: based on 4 essential natural frequencies:
-##   - given:   N = hi, mi, fa, cr
-##   - derived: all other values
-
-
-## -----------------------------------------------
-## (A) Define and initialize BASIC frequencies:
-## -----------------------------------------------
-## (0) N: population size
+##   (0) population size N: --------
 
 #' Number of individuals in the population.
 #'
@@ -62,46 +57,18 @@
 #' number of individuals in the current population
 #' (i.e., the overall number of cases considered).
 #'
-#' Key relationships:
+#' Key relationships between frequencies and probabilities
+#' (see documentation of \code{\link{comp_freq}} or \code{\link{comp_prob}} for details):
 #'
-#' \enumerate{
+#' \itemize{
 #'
-#' \item to probabilities:
-#' A population of \code{\link{N}} individuals can be split into 2 subsets
-#' in 2 different ways:
+#'   \item Three perspectives on a population:
 #'
-#' \enumerate{
-#'   \item by condition:
-#'   The frequency \code{\link{cond.true}} depends on the prevalence \code{\link{prev}}
-#'   and
-#'   the frequency \code{\link{cond.false}} depends on the prevalence's complement \code{1 - \link{prev}}.
+#'   by condition / by decision / by accuracy.
 #'
-#'   \item by decision:
-#'   The frequency \code{\link{dec.pos}} depends on the proportion of positive decisions \code{\link{ppod}}
-#'   and
-#'   the frequency \code{\link{dec.neg}} depends on the proportion of negative decisions \code{1 - \link{ppod}}.
+#'   \item Defining probabilities in terms of frequencies:
 #'
-#' }
-#'
-#' The population size \code{\link{N}} is a free parameter (independent of the
-#' essential probabilities \code{\link{prev}}, \code{\link{sens}}, and \code{\link{spec}}).
-#'
-#' If \code{\link{N}} is unknown, a suitable minimum value can be computed by \code{\link{comp_min_N}}.
-#'
-#'   \item to other frequencies:
-#'   In a population of size \code{\link{N}}
-#'   the following relationships hold:
-#'
-#'   \itemize{
-#'
-#'     \item \code{\link{N} = \link{cond.true} + \link{cond.false}} (by condition)
-#'
-#'     \item \code{\link{N} = \link{dec.pos} + \link{dec.neg}} (by decision)
-#'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
-#'
-#'     \item \code{\link{N} = \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
-#'   }
+#'   Probabilities can be computed as ratios between frequencies, but beware of rounding issues.
 #'
 #' }
 #'
@@ -131,10 +98,11 @@
 
 N <- 0  # default population size N
 
-## -----------------------------------------------
-## ***: 4 essential frequencies: hi mi fa cr
-## -----------------------------------------------
-## (1) hi*** = TP:
+
+
+## ***: 4 ESSENTIAL frequencies: SDT cases/classes of hi mi fa cr  -------
+
+##   (1) hi*** = TP: -------
 
 #' Frequency of hits or true positives (TP).
 #'
@@ -162,11 +130,11 @@ N <- 0  # default population size N
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N} = \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N} = \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N} = \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N} = \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N} = \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'    }
@@ -190,8 +158,8 @@ N <- 0  # default population size N
 
 hi <- 0  # default hits (TP)
 
-## -----------------------------------------------
-## (2) mi*** = FN:
+
+##   (2) mi*** = FN: -------
 
 #' Frequency of misses or false negatives (FN).
 #'
@@ -219,11 +187,11 @@ hi <- 0  # default hits (TP)
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N} = \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N} = \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N} = \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N} = \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N} = \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'    }
@@ -248,8 +216,8 @@ hi <- 0  # default hits (TP)
 
 mi <- 0  # default misses (FN)
 
-## -----------------------------------------------
-## (3) fa*** = FP:
+
+##   (3) fa*** = FP: -------
 
 #' Frequency of false alarms or false positives (FP).
 #'
@@ -277,11 +245,11 @@ mi <- 0  # default misses (FN)
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N} = \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N} = \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N} = \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N} = \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N} = \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'    }
@@ -307,8 +275,8 @@ mi <- 0  # default misses (FN)
 
 fa <- 0  # default false alarms (FP)
 
-## -----------------------------------------------
-## (4) cr*** = TN:
+
+##   (4) cr*** = TN: -------
 
 #' Frequency of correct rejections or true negatives (TN).
 #'
@@ -336,11 +304,11 @@ fa <- 0  # default false alarms (FP)
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N} = \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N} = \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N} = \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N} = \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N} = \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'    }
@@ -364,18 +332,21 @@ fa <- 0  # default false alarms (FP)
 
 cr <- 0  # default correct rejections (TN)
 
-## -----------------------------------------------
-## (B) Define and initialize COMBINED frequencies:
-## -----------------------------------------------
-## (a) by condition: cond.true vs. cond.false
-##     (= 2 columns of confusion matrix)
-## -----------------------------------------------
 
-## (5) cond.true
+
+## (B) COMBINED frequencies: ---------
+
+## 3 perspectives: Each combines 2 pairs of essential frequencies: --------
+
+## (a) by condition: cond_true vs. cond_false  ---------
+##     (= 2 columns of confusion matrix)
+
+
+##   (5) cond_true -------
 
 #' Number of individuals for which the condition is true.
 #'
-#' \code{cond.true} is a frequency that describes the
+#' \code{cond_true} is a frequency that describes the
 #' number of individuals in the current population \code{\link{N}}
 #' for which the condition is \code{TRUE} (i.e., actually true cases).
 #'
@@ -384,7 +355,7 @@ cr <- 0  # default correct rejections (TN)
 #' \enumerate{
 #'
 #' \item to probabilities:
-#' The frequency of \code{cond.true} individuals depends on the population size \code{\link{N}} and
+#' The frequency of \code{cond_true} individuals depends on the population size \code{\link{N}} and
 #' the condition's prevalence \code{\link{prev}} and is split further into two subsets of
 #' \code{\link{hi}} by the sensitivity \code{\link{sens}} and
 #' \code{\link{mi}} by the miss rate \code{\link{mirt}}.
@@ -394,21 +365,21 @@ cr <- 0  # default correct rejections (TN)
 #' \enumerate{
 #'   \item by condition:
 #'
-#'   The frequency \code{\link{cond.true}} is determined by the population size \code{\link{N}} times the prevalence \code{\link{prev}}:
+#'   The frequency \code{\link{cond_true}} is determined by the population size \code{\link{N}} times the prevalence \code{\link{prev}}:
 #'
-#'   \code{ \link{cond.true} = \link{N} x \link{prev}}
+#'   \code{ \link{cond_true} = \link{N} x \link{prev}}
 #'
 #'   \item by decision:
 #'
-#'   a. The frequency \code{\link{hi}} is determined by \code{\link{cond.true}} times the sensitivity \code{\link{sens}}
+#'   a. The frequency \code{\link{hi}} is determined by \code{\link{cond_true}} times the sensitivity \code{\link{sens}}
 #'   (aka. hit rate \code{\link{HR}}):
 #'
-#'   \code{ \link{hi} = \link{cond.true} x \link{sens}}
+#'   \code{ \link{hi} = \link{cond_true} x \link{sens}}
 #'
 #'
-#'   b. The frequency \code{\link{mi}} is determined by \code{\link{cond.true}} times the miss rate \code{\link{mirt} = (1 - \link{sens})}:
+#'   b. The frequency \code{\link{mi}} is determined by \code{\link{cond_true}} times the miss rate \code{\link{mirt} = (1 - \link{sens})}:
 #'
-#'   \code{ \link{mi} = \link{cond.true} x \link{mirt}  =  \link{cond.true} x (1 - \link{sens})}
+#'   \code{ \link{mi} = \link{cond_true} x \link{mirt}  =  \link{cond_true} x (1 - \link{sens})}
 #'
 #' }
 #'
@@ -418,11 +389,11 @@ cr <- 0  # default correct rejections (TN)
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N} = \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N} = \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N} = \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N} = \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N} = \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'   }
@@ -449,19 +420,18 @@ cr <- 0  # default correct rejections (TN)
 #' \code{\link{comp_prob}} computes current probability information.
 #'
 #' @examples
-#' cond.true <- 1000 * .10   # => sets cond.true to 10% of 1000 = 100 cases.
-#' is_freq(cond.true)        # => TRUE
-#' is_prob(cond.true)        # => FALSE, as cond.true is no probability (but prev and sens are)
+#' cond_true <- 1000 * .10   # => sets cond_true to 10% of 1000 = 100 cases.
+#' is_freq(cond_true)        # => TRUE
+#' is_prob(cond_true)        # => FALSE, as cond_true is no probability (but prev and sens are)
 
-cond.true <- 0  # default frequency of true cases
+cond_true <- 0  # default frequency of true cases
 
 
-## -----------------------------------------------
-## (6) cond.false
+##   (6) cond_false -------
 
 #' Number of individuals for which the condition is false.
 #'
-#' \code{cond.false} is a frequency that describes the
+#' \code{cond_false} is a frequency that describes the
 #' number of individuals in the current population \code{\link{N}}
 #' for which the condition is \code{FALSE} (i.e., actually false cases).
 #'
@@ -470,7 +440,7 @@ cond.true <- 0  # default frequency of true cases
 #' \enumerate{
 #'
 #' \item to probabilities:
-#' The frequency of \code{cond.false} individuals depends on the population size \code{\link{N}} and
+#' The frequency of \code{cond_false} individuals depends on the population size \code{\link{N}} and
 #' the complement of the condition's prevalence \code{1 - \link{prev}} and is split further into two subsets of
 #' \code{\link{fa}} by the false alarm rate \code{\link{fart}} and
 #' \code{\link{cr}} by the specificity \code{\link{spec}}.
@@ -480,21 +450,21 @@ cond.true <- 0  # default frequency of true cases
 #' \enumerate{
 #'   \item by condition:
 #'
-#'   The frequency \code{\link{cond.false}} is determined by the population size \code{\link{N}} times the complement of the prevalence \code{(1 - \link{prev})}:
+#'   The frequency \code{\link{cond_false}} is determined by the population size \code{\link{N}} times the complement of the prevalence \code{(1 - \link{prev})}:
 #'
-#'   \code{\link{cond.false}= \link{N} x (1 - \link{prev})}
+#'   \code{\link{cond_false}= \link{N} x (1 - \link{prev})}
 #'
 #'   \item by decision:
 #'
-#'   a. The frequency \code{\link{fa}} is determined by \code{\link{cond.false}} times the false alarm rate \code{\link{fart} = (1 - \link{spec})}
+#'   a. The frequency \code{\link{fa}} is determined by \code{\link{cond_false}} times the false alarm rate \code{\link{fart} = (1 - \link{spec})}
 #'   (aka. \code{\link{FPR}}):
 #'
-#'   \code{\link{fa} = \link{cond.false} x \link{fart} = \link{cond.false} x (1 - \link{spec}) }
+#'   \code{\link{fa} = \link{cond_false} x \link{fart} = \link{cond_false} x (1 - \link{spec}) }
 #'
 #'
-#'   b. The frequency \code{\link{cr}} is determined by \code{\link{cond.false}} times the specificity \code{\link{spec} = (1 - \link{fart})}:
+#'   b. The frequency \code{\link{cr}} is determined by \code{\link{cond_false}} times the specificity \code{\link{spec} = (1 - \link{fart})}:
 #'
-#'   \code{\link{cr}  =  \link{cond.false} x \link{spec}  =  \link{cond.false} x (1 - \link{fart}) }
+#'   \code{\link{cr}  =  \link{cond_false} x \link{spec}  =  \link{cond_false} x (1 - \link{fart}) }
 #'
 #' }
 #'
@@ -504,11 +474,11 @@ cond.true <- 0  # default frequency of true cases
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N} = \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N} = \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N} = \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N} = \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N} = \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'   }
@@ -535,23 +505,24 @@ cond.true <- 0  # default frequency of true cases
 #' \code{\link{comp_prob}} computes current probability information.
 #'
 #' @examples
-#' cond.false <- 1000 * .90  # => sets cond.false to 90% of 1000 = 900 cases.
-#' is_freq(cond.false)       # => TRUE
-#' is_prob(cond.false)       # => FALSE, as cond.false is no probability [but (1 - prev) and spec are]
+#' cond_false <- 1000 * .90  # => sets cond_false to 90% of 1000 = 900 cases.
+#' is_freq(cond_false)       # => TRUE
+#' is_prob(cond_false)       # => FALSE, as cond_false is no probability [but (1 - prev) and spec are]
 
-cond.false <- 0  # default frequency of false cases
+cond_false <- 0  # default frequency of false cases
 
 
-## -----------------------------------------------
-## (b) by decision: dec.pos vs. dec.neg
+
+
+## (b) by decision: dec_pos vs. dec_neg ----------
 ##     (= 2 rows of confusion matrix)
-## -----------------------------------------------
 
-## (7) dec.pos
+
+##   (7) dec_pos  -------
 
 #' Number of individuals for which the decision is positive.
 #'
-#' \code{dec.pos} is a frequency that describes the
+#' \code{dec_pos} is a frequency that describes the
 #' number of individuals in the current population \code{\link{N}}
 #' for which the decision is positive (i.e., called or predicted cases).
 #'
@@ -560,7 +531,7 @@ cond.false <- 0  # default frequency of false cases
 #' \enumerate{
 #'
 #' \item to probabilities:
-#' The frequency of \code{dec.pos} individuals depends on the population size \code{\link{N}} and
+#' The frequency of \code{dec_pos} individuals depends on the population size \code{\link{N}} and
 #' the decision's proportion of positive decisions \code{\link{ppod}} and is split further into two subsets of
 #' \code{\link{hi}} by the positive predictive value \code{\link{PPV}} and
 #' \code{\link{fa}} by the false detection rate \code{\link{FDR} = 1 - \link{PPV}}.
@@ -570,22 +541,22 @@ cond.false <- 0  # default frequency of false cases
 #' \enumerate{
 #'   \item by condition:
 #'
-#'   The frequency \code{\link{dec.pos}} is determined by the population size \code{\link{N}} times
+#'   The frequency \code{\link{dec_pos}} is determined by the population size \code{\link{N}} times
 #'   the proportion of positive decisions \code{\link{ppod}}:
 #'
-#'   \code{\link{dec.pos}  =  \link{N} x \link{ppod}}
+#'   \code{\link{dec_pos}  =  \link{N} x \link{ppod}}
 #'
 #'   \item by decision:
 #'
-#'   a. The frequency \code{\link{hi}} is determined by \code{\link{dec.pos}} times the positive predictive value \code{\link{PPV}}
+#'   a. The frequency \code{\link{hi}} is determined by \code{\link{dec_pos}} times the positive predictive value \code{\link{PPV}}
 #'   (aka. \code{\link{precision}}):
 #'
-#'   \code{\link{hi}  =  \link{dec.pos} x \link{PPV}}
+#'   \code{\link{hi}  =  \link{dec_pos} x \link{PPV}}
 #'
 #'
-#'   b. The frequency \code{\link{fa}} is determined by \code{\link{dec.pos}} times the false detection rate \code{\link{FDR} = (1 - \link{PPV})}:
+#'   b. The frequency \code{\link{fa}} is determined by \code{\link{dec_pos}} times the false detection rate \code{\link{FDR} = (1 - \link{PPV})}:
 #'
-#'   \code{\link{fa}  =  \link{dec.pos} x \link{FDR}  =  \link{dec.pos} x (1 - \link{PPV})}
+#'   \code{\link{fa}  =  \link{dec_pos} x \link{FDR}  =  \link{dec_pos} x (1 - \link{PPV})}
 #'
 #' }
 #'
@@ -595,11 +566,11 @@ cond.false <- 0  # default frequency of false cases
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N}  =  \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N}  =  \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N}  =  \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N}  =  \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N}  =  \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'   }
@@ -626,20 +597,18 @@ cond.false <- 0  # default frequency of false cases
 #' \code{\link{comp_prob}} computes current probability information.
 #'
 #' @examples
-#' dec.pos <- 1000 * .33   # => sets dec.pos to 33% of 1000 = 330 cases.
-#' is_freq(dec.pos)        # => TRUE
-#' is_prob(dec.pos)        # => FALSE, as dec.pos is no probability (but ppod and PPV are)
+#' dec_pos <- 1000 * .33   # => sets dec_pos to 33% of 1000 = 330 cases.
+#' is_freq(dec_pos)        # => TRUE
+#' is_prob(dec_pos)        # => FALSE, as dec_pos is no probability (but ppod and PPV are)
 
-dec.pos <- 0  # default frequency of positive decisions
+dec_pos <- 0  # default frequency of positive decisions
 
 
-## -----------------------------------------------
-
-## (8) dec.neg
+##   (8) dec_neg -------
 
 #' Number of individuals for which the decision is negative.
 #'
-#' \code{dec.neg} is a frequency that describes the
+#' \code{dec_neg} is a frequency that describes the
 #' number of individuals in the current population \code{\link{N}}
 #' for which the decision is negative (i.e., cases not called or not predicted).
 #'
@@ -648,7 +617,7 @@ dec.pos <- 0  # default frequency of positive decisions
 #' \enumerate{
 #'
 #' \item to probabilities:
-#' The frequency of \code{dec.neg} individuals depends on the population size \code{\link{N}} and
+#' The frequency of \code{dec_neg} individuals depends on the population size \code{\link{N}} and
 #' the decision's proportion of negative decisions \code{(1 - \link{ppod})} and is split further into two subsets of
 #' \code{\link{cr}} by the negative predictive value \code{\link{NPV}} and
 #' \code{\link{mi}} by the false omission rate \code{\link{FOR} = 1 - \link{NPV}}.
@@ -658,21 +627,21 @@ dec.pos <- 0  # default frequency of positive decisions
 #' \enumerate{
 #'   \item by condition:
 #'
-#'   The frequency \code{\link{dec.neg}} is determined by the population size \code{\link{N}} times
+#'   The frequency \code{\link{dec_neg}} is determined by the population size \code{\link{N}} times
 #'   the proportion of negative decisions \code{(1 - \link{ppod})}:
 #'
-#'   \code{\link{dec.neg}  =  \link{N} x (1 - \link{ppod})}
+#'   \code{\link{dec_neg}  =  \link{N} x (1 - \link{ppod})}
 #'
 #'   \item by decision:
 #'
-#'   a. The frequency \code{\link{cr}} is determined by \code{\link{dec.neg}} times the negative predictive value \code{\link{NPV}}:
+#'   a. The frequency \code{\link{cr}} is determined by \code{\link{dec_neg}} times the negative predictive value \code{\link{NPV}}:
 #'
-#'   \code{\link{cr}  =  \link{dec.neg} x \link{NPV}}
+#'   \code{\link{cr}  =  \link{dec_neg} x \link{NPV}}
 #'
 #'
-#'   b. The frequency \code{\link{mi}} is determined by \code{\link{dec.neg}} times the false omission rate \code{\link{FOR} = (1 - \link{NPV})}:
+#'   b. The frequency \code{\link{mi}} is determined by \code{\link{dec_neg}} times the false omission rate \code{\link{FOR} = (1 - \link{NPV})}:
 #'
-#'   \code{\link{mi}  =  \link{dec.neg} x \link{FOR}  =  \link{dec.neg} x (1 - \link{NPV})}
+#'   \code{\link{mi}  =  \link{dec_neg} x \link{FOR}  =  \link{dec_neg} x (1 - \link{NPV})}
 #'
 #' }
 #'
@@ -682,11 +651,11 @@ dec.pos <- 0  # default frequency of positive decisions
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N}  =  \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N}  =  \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N}  =  \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N}  =  \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
 #'     \item \code{\link{N}  =  \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'   }
@@ -713,54 +682,62 @@ dec.pos <- 0  # default frequency of positive decisions
 #' \code{\link{comp_prob}} computes current probability information.
 #'
 #' @examples
-#' dec.neg <- 1000 * .67   # => sets dec.neg to 67% of 1000 = 670 cases.
-#' is_freq(dec.neg)        # => TRUE
-#' is_prob(dec.neg)        # => FALSE, as dec.neg is no probability (but ppod, NPV and FOR are)
+#' dec_neg <- 1000 * .67   # => sets dec_neg to 67% of 1000 = 670 cases.
+#' is_freq(dec_neg)        # => TRUE
+#' is_prob(dec_neg)        # => FALSE, as dec_neg is no probability (but ppod, NPV and FOR are)
 
-dec.neg <- 0  # default frequency of negative decisions
+dec_neg <- 0  # default frequency of negative decisions
 
 
-## -----------------------------------------------
-## (c) by correspondence of decision to condition:
-##     dec.cor vs. dec.err
-##     (= 2 diagonals of confusion matrix)
-## -----------------------------------------------
 
-## (9) dec.cor
+## (c) by accuracy/correspondence of decision to condition: ---------
+##     dec_cor vs. dec_err (= 2 diagonals of confusion matrix)
+
+##   (9) dec_cor --------
+
+# NOTE: "dec_cor" should better be called "dec_acc"
+#       (for consistency with probabilities "acc" vs. "err")!
 
 #' Number of individuals for which the decision is correct.
 #'
-#' \code{dec.cor} is a frequency that describes the
+#' \code{dec_cor} is a frequency that describes the
 #' number of individuals in the current population \code{\link{N}}
-#' for which the decision is correct (i.e., cases in which the
-#' decision corresponds to the condition).
+#' for which the decision is correct/accurate
+#' (i.e., cases in which the decision corresponds to the condition).
 #'
 #' Key relationships:
 #'
 #' \enumerate{
 #'
 #' \item to probabilities:
-#' The frequency of \code{dec.cor} individuals depends on the population size \code{\link{N}} and
-#' is equal to the sum of true positives \code{\link{hi}} and true negatives \code{\link{cr}}.
+#' The frequency of \code{dec_cor} individuals depends on the population size \code{\link{N}} and
+#' the accuracy \code{\link{acc}}.
 #'
 #' \item to other frequencies:
-#'In a population of size \code{\link{N}} the following relationships hold:
+#' In a population of size \code{\link{N}} the following relationships hold:
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N}  =  \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N}  =  \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N}  =  \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N}  =  \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
-#'     \item \code{\link{dec.cor} = \link{hi} + \link{cr}}
+#'     \item \code{\link{dec_cor} = \link{hi} + \link{cr}}
 #'
-#'     \item \code{\link{dec.err} = \link{mi} + \link{fa}}
+#'     \item \code{\link{dec_err} = \link{mi} + \link{fa}}
 #'
 #'     \item \code{\link{N}  =  \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'   }
 #'
+#' \item correspondence:
+#' When not rounding the frequencies of \code{\link{freq}} then
+#'
+#' \code{dec_cor = N x acc = hi + cr}
+#'
+#' (i.e., \code{dec_cor} corresponds to the sum of true positives \code{\link{hi}} and true negatives \code{\link{cr}}.
+#'
 #' }
 #'
 #' Current frequency information is computed by
@@ -783,20 +760,19 @@ dec.neg <- 0  # default frequency of negative decisions
 #' \code{\link{comp_prob}} computes current probability information.
 #'
 #' @examples
-#' dec.cor <- 1000 * .50   # => sets dec.cor to 50% of 1000 = 500 cases.
-#' is_freq(dec.cor)        # => TRUE
-#' is_prob(dec.cor)        # => FALSE, as dec.cor is no probability (but acc, bacc/wacc ARE)
+#' dec_cor <- 1000 * .50   # => sets dec_cor to 50% of 1000 = 500 cases.
+#' is_freq(dec_cor)        # => TRUE
+#' is_prob(dec_cor)        # => FALSE, as dec_cor is no probability (but acc, bacc/wacc ARE)
 
-dec.cor <- 0  # default frequency of negative decisions
+dec_cor <- 0  # default frequency of negative decisions
 
 
-## -----------------------------------------------
 
-## (10) dec.err
+##  (10) dec_err --------
 
 #' Number of individuals for which the decision is erroneous.
 #'
-#' \code{dec.err} is a frequency that describes the
+#' \code{dec_err} is a frequency that describes the
 #' number of individuals in the current population \code{\link{N}}
 #' for which the decision is incorrect or erroneous (i.e., cases in which the
 #' decision does not correspond to the condition).
@@ -806,7 +782,7 @@ dec.cor <- 0  # default frequency of negative decisions
 #' \enumerate{
 #'
 #' \item to probabilities:
-#' The frequency of \code{dec.err} individuals depends on the population size \code{\link{N}} and
+#' The frequency of \code{dec_err} individuals depends on the population size \code{\link{N}} and
 #' is equal to the sum of false negatives \code{\link{mi}} and false positives \code{\link{fa}}.
 #'
 #' \item to other frequencies:
@@ -814,15 +790,15 @@ dec.cor <- 0  # default frequency of negative decisions
 #'
 #'   \itemize{
 #'
-#'     \item \code{\link{N}  =  \link{cond.true} + \link{cond.false}} (by condition)
+#'     \item \code{\link{N}  =  \link{cond_true} + \link{cond_false}} (by condition)
 #'
-#'     \item \code{\link{N}  =  \link{dec.pos} + \link{dec.neg}} (by decision)
+#'     \item \code{\link{N}  =  \link{dec_pos} + \link{dec_neg}} (by decision)
 #'
-#'     \item \code{\link{N} = \link{dec.cor} + \link{dec.err}} (by correspondence of decision to condition)
+#'     \item \code{\link{N} = \link{dec_cor} + \link{dec_err}} (by correspondence of decision to condition)
 #'
-#'     \item \code{\link{dec.cor} = \link{hi} + \link{cr}}
+#'     \item \code{\link{dec_cor} = \link{hi} + \link{cr}}
 #'
-#'     \item \code{\link{dec.err} = \link{mi} + \link{fa}}
+#'     \item \code{\link{dec_err} = \link{mi} + \link{fa}}
 #'
 #'     \item \code{\link{N}  =  \link{hi} + \link{mi} + \link{fa} + \link{cr}} (by condition x decision)
 #'   }
@@ -849,15 +825,19 @@ dec.cor <- 0  # default frequency of negative decisions
 #' \code{\link{comp_prob}} computes current probability information.
 #'
 #' @examples
-#' dec.err <- 1000 * .50   # => sets dec.err to 50% of 1000 = 500 cases.
-#' is_freq(dec.err)        # => TRUE
-#' is_prob(dec.err)        # => FALSE, as dec.err is no probability (but acc, bacc/wacc ARE)
+#' dec_err <- 1000 * .50   # => sets dec_err to 50% of 1000 = 500 cases.
+#' is_freq(dec_err)        # => TRUE
+#' is_prob(dec_err)        # => FALSE, as dec_err is no probability (but acc, bacc/wacc ARE)
 
-dec.err <- 0  # default frequency of negative decisions
-
-## -----------------------------------------------
-## (+) ToDo:
+dec_err <- 0  # default frequency of negative decisions
 
 
-## -----------------------------------------------
-## eof.
+## (*) Done: -----------
+
+## - Clean up code [2018 09 02].
+
+## (+) ToDo: ----------
+
+## - ...
+
+## eof. ------------------------------------------
