@@ -1,18 +1,16 @@
 ## init_prob.R | riskyr
-## 2018 02 08
-## -----------------------------------------------
+## 2018 12 20
 ## Define and initialize ALL probabilities
 ## -----------------------------------------------
 
-## -----------------------------------------------
-## Table of current terminology:
+## Table of current terminology: -----------------
 
-# Probabilities (10):               Frequencies (11):
+# Probabilities (13+):              Frequencies (11):
 # -------------------               ------------------
 # (A) by condition:
 
 # non-conditional:                          N
-# prev*                           cond.true | cond.false (columns)
+# prev*                           cond_true | cond_false (columns)
 
 # conditional:
 # sens* = hit rate = TPR                hi* = TP
@@ -26,8 +24,8 @@
 # (B) by decision:                 Combined frequencies:
 
 # non-conditional:
-# ppod = proportion of dec.pos     dec.pos | dec.neg (rows)
-#                                  dec.cor | dec.err (diagonal)
+# ppod = proportion of dec_pos     dec_pos | dec_neg (rows)
+#                                  dec_cor | dec_err (diagonal)
 
 # conditional:
 # PPV = precision
@@ -35,8 +33,22 @@
 # FOR = false omission rate
 # NPV = neg. pred. value
 
-## -----------------------------------------------
-## Data flow: Two basic directions:
+# (C) by accuracy/correspondence of decision to condition (see accu):
+
+# acc  = overall accuracy (probability/proportion correct decision)
+# p_acc_hi = p(hi|acc)  # aka. acc-hi  "p(hi | dec_cor)"
+# p_err_fa = p(fa|err)  # aka. err-fa  "p(fa | dec_err)"
+
+## Other measures of accuracy (in accu):
+# wacc = weighted accuracy
+# mcc  = Matthews correlation coefficient
+# f1s  = harmonic mean of PPV and sens
+
+# err = error rate = (1 - acc)
+
+
+
+## Data flow: Two basic directions: --------------
 
 ## (1) Probabilities ==> frequencies:
 ##     Bayesian: based on 3 essential probabilities:
@@ -49,15 +61,11 @@
 ##   - derived: all other values
 
 
-## -----------------------------------------------
-## A: Define probabilities by condition:
-## -----------------------------------------------
+## A: Define probabilities by condition: ---------
 
-## -----------------------------------------------
-## ***: 3 essential probabilities: prev; sens, spec
-## -----------------------------------------------
+## ***: 3 essential probabilities: prev; sens, spec/fart.
 
-## (0) prev*** = base rate of condition:
+## (0) prev*** = base rate of condition: ---------
 
 #' The prevalence (baseline probability) of a condition.
 #'
@@ -75,76 +83,74 @@
 #'   \code{prev = p(condition = TRUE)}
 #'
 #'   or the base rate (or baseline probability)
-#'   of the condition's occurrence.
-#'
+#'   of the condition's occurrence or truth.
 #'
 #'   \item In terms of frequencies,
 #'   \code{prev} is the ratio of
-#'   \code{\link{cond.true}} (i.e., \code{\link{hi} + \link{mi}})
+#'   \code{\link{cond_true}} (i.e., \code{\link{hi} + \link{mi}})
 #'   divided by \code{\link{N}} (i.e.,
 #'   \code{\link{hi} + \link{mi}} + \code{\link{fa} + \link{cr}}):
 #'
-#'   \code{prev = cond.true/N = (hi + mi)/(hi + mi + fa + cr)}
-#'
+#'   \code{prev = cond_true/N = (hi + mi)/(hi + mi + fa + cr)}
 #'
 #'   \item Perspective:
 #'   \code{prev} classifies a population of \code{\link{N}} individuals
-#'   by condition (\code{prev = cond.true/N}).
-#'
-#'   \code{prev} is the "by condition" counterpart to \code{\link{ppod}}
-#'   (which adopts a "by decision" perspective).
+#'   by condition (\code{prev = cond_true/N}).
 #'
+#'   \code{prev} is the "by condition" counterpart
+#'   to \code{\link{ppod}} (when adopting a "by decision" perspective) and
+#'   to \code{\link{acc}}  (when adopting a "by accuracy" perspective).
 #'
 #'   \item Alternative names:
 #'   base rate of condition,
 #'   proportion affected,
-#'   rate of condition \code{= TRUE} cases
+#'   rate of condition \code{= TRUE} cases.
 #'
 #'   \code{prev} is often distinguished from the \emph{incidence rate}
 #'   (i.e., the rate of new cases within a certain time period).
 #'
-#'
 #'   \item Dependencies:
 #'   \code{prev} is a feature of the population
-#'   and condition, but independent of the decision process
+#'   and of the condition, but independent of the decision process
 #'   or diagnostic procedure.
 #'
-#'   The value of \code{prev} does \emph{not} depend
-#'   on features of the decision process or diagnostic procedure.
-#'   However, \code{prev} must be taken into account when
+#'   While the value of \code{prev} does \emph{not} depend
+#'   on features of the decision process or diagnostic procedure,
+#'   \code{prev} must be taken into account when
 #'   computing the conditional probabilities
 #'   \code{\link{sens}}, \code{\link{mirt}},
 #'   \code{\link{spec}}, \code{\link{fart}},
 #'   \code{\link{PPV}}, and \code{\link{NPV}}
-#'   (as they partly depend on \code{prev}).
+#'   (as they depend on \code{prev}).
 #'
 #' }
 #'
 #' @aliases
-#' baserate_cond.true
+#' baserate_cond_true
 #'
 #' @examples
-#' prev <- .10     # => sets a prevalence value of 10%
-#' prev <- 10/100  # => (condition = TRUE) for 10 out of 100 individuals
-#' is_prob(prev)   # => TRUE (as prev is a probability)
+#' prev <- .10     # sets a prevalence value of 10%
+#' prev <- 10/100  # (condition = TRUE) for 10 out of 100 individuals
+#' is_prob(prev)   # TRUE
 #'
 #' @family probabilities
 #' @family essential parameters
 #'
 #' @seealso
+#' \code{\link{prob}} contains current probability information;
 #' \code{\link{num}} contains basic numeric variables;
 #' \code{\link{init_num}} initializes basic numeric variables;
-#' \code{\link{is_prob}} verifies probability inputs;
 #' \code{\link{comp_prob}} computes derived probabilities;
-#' \code{\link{comp_freq}} computes natural frequencies from probabilities
+#' \code{\link{comp_freq}} computes natural frequencies from probabilities;
+#' \code{\link{is_prob}} verifies probabilities.
 #'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Prevalence}{Wikipedia} for additional information.
 
 prev <- 1/2  # default prevalence
 
-## -----------------------------------------------
-## (1) sens*** = TPR:
+
+## (1) sens*** = TPR: ----------------------------
 
 #' The sensitivity (or hit rate) of a decision process or diagnostic procedure.
 #'
@@ -169,8 +175,8 @@ prev <- 1/2  # default prevalence
 #'
 #'   \item Perspective:
 #'   \code{sens} further classifies
-#'   the subset of \code{\link{cond.true}} individuals
-#'   by decision (\code{sens = hi/cond.true}).
+#'   the subset of \code{\link{cond_true}} individuals
+#'   by decision (\code{sens = hi/cond_true}).
 #'
 #'
 #'   \item Alternative names:
@@ -179,7 +185,6 @@ prev <- 1/2  # default prevalence
 #'   probability of detection,
 #'   \code{power = 1 - beta},
 #'   \code{recall}
-
 #'
 #'   \item Relationships:
 #'
@@ -194,14 +199,13 @@ prev <- 1/2  # default prevalence
 #'   of the positive predictive value \code{\link{PPV}}:
 #'
 #'   \code{PPV = p(condition = TRUE | decision = positive)}
-
 #'
 #'   \item In terms of frequencies,
 #'   \code{sens} is the ratio of
 #'   \code{\link{hi}} divided by
-#'   \code{\link{cond.true}} (i.e., \code{\link{hi} + \link{mi}}):
+#'   \code{\link{cond_true}} (i.e., \code{\link{hi} + \link{mi}}):
 #'
-#'   \code{sens = hi/cond.true = hi/(hi + mi)}
+#'   \code{sens = hi/cond_true = hi/(hi + mi)}
 #'
 #'
 #'   \item Dependencies:
@@ -217,8 +221,7 @@ prev <- 1/2  # default prevalence
 #' }
 #'
 #' @aliases
-#' TPR HR
-#' power recall
+#' TPR HR power recall
 #'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Sensitivity_and_specificity}{Wikipedia} for additional information.
@@ -233,17 +236,17 @@ prev <- 1/2  # default prevalence
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
+#' \code{\link{is_prob}} verifies probabilities.
 #'
 #' @examples
-#' sens <- .85     # => sets a sensitivity value of 85%
-#' sens <- 85/100  # => (decision = positive) for 85 out of 100 people with (condition = TRUE)
-#' is_prob(sens)   # => TRUE (as sens is a probability)
+#' sens <- .85     # sets a sensitivity value of 85%
+#' sens <- 85/100  # (decision = positive) for 85 out of 100 people with (condition = TRUE)
+#' is_prob(sens)   # TRUE
 
 sens <- 1/2  # default sensitivity
 
-## -----------------------------------------------
-## (2) mirt = FNR:
+
+## (2) mirt = FNR: -------------------------------
 
 #' The miss rate of a decision process or diagnostic procedure.
 #'
@@ -264,18 +267,16 @@ sens <- 1/2  # default sensitivity
 #'   or the probability of failing to detect true cases
 #'   (\code{condition = TRUE}).
 #'
-
 #'   \item Perspective:
 #'   \code{mirt} further classifies
-#'   the subset of \code{\link{cond.true}} individuals
-#'   by decision (\code{mirt = mi/cond.true}).
+#'   the subset of \code{\link{cond_true}} individuals
+#'   by decision (\code{mirt = mi/cond_true}).
 #'
 #'
 #'   \item Alternative names:
 #'   false negative rate (\code{FNR}),
 #'   rate of type-II errors (\code{beta})
 #'
-
 #'   \item Relationships:
 #'
 #'   a. \code{mirt} is the complement of the
@@ -289,13 +290,12 @@ sens <- 1/2  # default sensitivity
 #'
 #'   \code{FOR = p(condition = TRUE | decision = negative)}
 #'
-
 #'   \item In terms of frequencies,
 #'   \code{mirt} is the ratio of
-#'   \code{\link{mi}} divided by \code{\link{cond.true}}
+#'   \code{\link{mi}} divided by \code{\link{cond_true}}
 #'   (i.e., \code{\link{hi} + \link{mi}}):
 #'
-#'   \code{mirt = mi/cond.true = mi/(hi + mi)}
+#'   \code{mirt = mi/cond_true = mi/(hi + mi)}
 #'
 #'
 #'   \item Dependencies:
@@ -311,8 +311,7 @@ sens <- 1/2  # default sensitivity
 #' }
 #'
 #' @aliases
-#' FNR
-#' beta
+#' FNR beta
 #'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Sensitivity_and_specificity}{Wikipedia} for additional information.
@@ -326,17 +325,16 @@ sens <- 1/2  # default sensitivity
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
+#' \code{\link{is_prob}} verifies probabilities.
 #'
 #' @examples
 #' mirt <- .15     # => sets a miss rate of 15%
 #' mirt <- 15/100  # => (decision = negative) for 15 out of 100 people with (condition = TRUE)
-#' is_prob(mirt)   # => TRUE (as mirt is a probability)
 
 mirt <- 1 - sens  # default miss rate
 
-## -----------------------------------------------
-## (3) spec*** = TNR:
+
+## (3) spec*** = TNR: ----------------------------
 
 #' The specificity of a decision process or diagnostic procedure.
 #'
@@ -360,8 +358,8 @@ mirt <- 1 - sens  # default miss rate
 #'
 #'   \item Perspective:
 #'   \code{spec} further classifies
-#'   the subset of \code{\link{cond.false}} individuals
-#'   by decision (\code{spec = cr/cond.false}).
+#'   the subset of \code{\link{cond_false}} individuals
+#'   by decision (\code{spec = cr/cond_false}).
 #'
 #'
 #'   \item Alternative names:
@@ -386,10 +384,10 @@ mirt <- 1 - sens  # default miss rate
 #'
 #'   \item In terms of frequencies,
 #'   \code{spec} is the ratio of
-#'   \code{\link{cr}} divided by \code{\link{cond.false}}
+#'   \code{\link{cr}} divided by \code{\link{cond_false}}
 #'   (i.e., \code{\link{fa} + \link{cr}}):
 #'
-#'   \code{spec = cr/cond.false = cr/(fa + cr)}
+#'   \code{spec = cr/cond_false = cr/(fa + cr)}
 #'
 #'
 #'   \item Dependencies:
@@ -407,6 +405,11 @@ mirt <- 1 - sens  # default miss rate
 #' @aliases
 #' TNR
 #'
+#' @examples
+#' spec <- .75     # sets a specificity value of 75%
+#' spec <- 75/100  # (decision = negative) for 75 out of 100 people with (condition = FALSE)
+#' is_prob(spec)   # TRUE
+#'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Sensitivity_and_specificity}{Wikipedia} for additional information.
 #'
@@ -420,17 +423,12 @@ mirt <- 1 - sens  # default miss rate
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
-#'
-#' @examples
-#' spec <- .75     # => sets a specificity value of 75%
-#' spec <- 75/100  # => (decision = negative) for 75 out of 100 people with (condition = FALSE)
-#' is_prob(spec)   # => TRUE (as spec is a probability)
+#' \code{\link{is_prob}} verifies probabilities.
 
 spec <- 1/2 # default specificity
 
-## -----------------------------------------------
-## (4) fart = FPR:
+
+## (4) fart = FPR: -------------------------------
 
 #' The false alarm rate (or false positive rate) of a decision process or diagnostic procedure.
 #'
@@ -454,8 +452,8 @@ spec <- 1/2 # default specificity
 #'
 #'   \item Perspective:
 #'   \code{fart} further classifies
-#'   the subset of \code{\link{cond.false}} individuals
-#'   by decision (\code{fart = fa/cond.false}).
+#'   the subset of \code{\link{cond_false}} individuals
+#'   by decision (\code{fart = fa/cond_false}).
 #'
 #'
 #'   \item Alternative names:
@@ -482,10 +480,10 @@ spec <- 1/2 # default specificity
 #'
 #'   \item In terms of frequencies,
 #'   \code{fart} is the ratio of
-#'   \code{\link{fa}} divided by \code{\link{cond.false}}
+#'   \code{\link{fa}} divided by \code{\link{cond_false}}
 #'   (i.e., \code{\link{fa} + \link{cr}}):
 #'
-#'   \code{fart = fa/cond.false = fa/(fa + cr)}
+#'   \code{fart = fa/cond_false = fa/(fa + cr)}
 #'
 #'
 #'   \item Dependencies:
@@ -505,6 +503,11 @@ spec <- 1/2 # default specificity
 #' alpha
 #' fallout
 #'
+#' @examples
+#' fart <- .25     # sets a false alarm rate of 25%
+#' fart <- 25/100  # (decision = positive) for 25 out of 100 people with (condition = FALSE)
+#' is_prob(fart)   # TRUE
+#'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Sensitivity_and_specificity}{Wikipedia} for additional information.
 #'
@@ -517,27 +520,21 @@ spec <- 1/2 # default specificity
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
-#'
-#' @examples
-#' fart <- .25     # => sets a false alarm rate of 25%
-#' fart <- 25/100  # => (decision = positive) for 25 out of 100 people with (condition = FALSE)
-#' is_prob(fart)   # => TRUE (as fart is a probability)
+#' \code{\link{is_prob}} verifies probabilities.
 
 fart <- 1 - spec   # default false alarm rate
 
 
-## -----------------------------------------------
-## B: Define by decision:
-## -----------------------------------------------
-## (0) Base rate of positive decisions (PR):
+## B: Define probabilities by decision: ------------------------
 
-## (0) ppod = base rate of decisions being positive (PR):
+## (0) Proportion of positive decisions (ppod, PR): -----
+
+## (0) ppod = proportion/base rate of decisions being positive (PR):
 
 #' The proportion (or baseline) of a positive decision.
 #'
-#' \code{ppod} defines the proportion (baseline probability or rate):
-#' a decision being \code{positive} (but not necessarily true).
+#' \code{ppod} defines the proportion (baseline probability or rate) of
+#' a decision being \code{positive} (but not necessarily accurate/correct).
 #'
 #' Understanding or obtaining the proportion of positive decisions \code{ppod}:
 #'
@@ -549,31 +546,27 @@ fart <- 1 - spec   # default false alarm rate
 #'   \code{ppod = p(decision = positive)}
 #'
 #'   or the base rate (or baseline probability)
-#'   of a decision being positive (but not necessarily true).
-#'
+#'   of a decision being positive (but not necessarily accurate/correct).
 #'
 #'   \item Perspective:
 #'   \code{ppod} classifies a population of \code{\link{N}} individuals
-#'   by decision (\code{ppod = dec.pos/N}).
+#'   by decision (\code{ppod = dec_pos/N}).
 #'
 #'   \code{ppod} is the "by decision" counterpart to \code{\link{prev}}
 #'   (which adopts a "by condition" perspective).
 #'
-#'
 #'   \item Alternative names:
 #'   base rate of positive decisions (\code{PR}),
 #'   proportion predicted or diagnosed,
 #'   rate of decision \code{= positive} cases
 #'
-#'
 #'   \item In terms of frequencies,
 #'   \code{ppod} is the ratio of
-#'   \code{\link{dec.pos}} (i.e., \code{\link{hi} + \link{fa}})
+#'   \code{\link{dec_pos}} (i.e., \code{\link{hi} + \link{fa}})
 #'   divided by \code{\link{N}} (i.e.,
 #'   \code{\link{hi} + \link{mi}} + \code{\link{fa} + \link{cr}}):
 #'
-#'   \code{ppod = dec.pos/N = (hi + fa)/(hi + mi + fa + cr)}
-#'
+#'   \code{ppod = dec_pos/N = (hi + fa)/(hi + mi + fa + cr)}
 #'
 #'   \item Dependencies:
 #'   \code{ppod} is a feature of the decision process
@@ -588,12 +581,12 @@ fart <- 1 - spec   # default false alarm rate
 #' }
 #'
 #' @aliases
-#' baserate_dec.pos PR
+#' baserate_dec_pos PR
 #'
 #' @examples
-#' ppod <- .50     # => sets a rate of positive decisions of 50%
-#' ppod <- 50/100  # => (decision = TRUE) for 50 out of 100 individuals
-#' is_prob(ppod)   # => TRUE (as ppod is a probability)
+#' ppod <- .50     # sets a rate of positive decisions of 50%
+#' ppod <- 50/100  # (decision = TRUE) for 50 out of 100 individuals
+#' is_prob(ppod)   # TRUE
 #'
 #' @family probabilities
 #'
@@ -604,19 +597,17 @@ fart <- 1 - spec   # default false alarm rate
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{freq}} contains current frequency information;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
-#'
+#' \code{\link{is_prob}} verifies probabilities.
 #'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Positive_and_negative_predictive_values}{Wikipedia} for additional information.
 
 ppod <- 1/2  # default rate of positive decisions
 
-## -----------------------------------------------
-## Predictive values (PVs):
 
+## Predictive values (PVs): ----------------------
 
-## (1) PPV: positive predictive value
+## (1) PPV: positive predictive value ------------
 
 #' The positive predictive value of a decision process or diagnostic procedure.
 #'
@@ -640,8 +631,8 @@ ppod <- 1/2  # default rate of positive decisions
 #'
 #'   \item Perspective:
 #'   \code{PPV} further classifies
-#'   the subset of \code{\link{dec.pos}} individuals
-#'   by condition (\code{PPV = hi/dec.pos = hi/(hi + fa)}).
+#'   the subset of \code{\link{dec_pos}} individuals
+#'   by condition (\code{PPV = hi/dec_pos = hi/(hi + fa)}).
 #'
 #'
 #'   \item Alternative names:
@@ -660,14 +651,13 @@ ppod <- 1/2  # default rate of positive decisions
 #'   of the sensitivity \code{\link{sens}}:
 #'
 #'   \code{sens = p(decision = positive | condition = TRUE)}
-
 #'
 #'   \item In terms of frequencies,
 #'   \code{PPV} is the ratio of
-#'   \code{\link{hi}} divided by \code{\link{dec.pos}}
+#'   \code{\link{hi}} divided by \code{\link{dec_pos}}
 #'   (i.e., \code{\link{hi} + \link{fa}}):
 #'
-#'   \code{PPV = hi/dec.pos = hi/(hi + fa)}
+#'   \code{PPV = hi/dec_pos = hi/(hi + fa)}
 #'
 #'
 #'   \item Dependencies:
@@ -691,9 +681,9 @@ ppod <- 1/2  # default rate of positive decisions
 #' Consult \href{https://en.wikipedia.org/wiki/Positive_and_negative_predictive_values}{Wikipedia} for additional information.
 #'
 #' @examples
-#' PPV <- .55     # => sets a positive predictive value of 55%
-#' PPV <- 55/100  # => (condition = TRUE) for 55 out of 100 people with (decision = positive)
-#' is_prob(PPV)   # => TRUE (as PPV is a probability)
+#' PPV <- .55     # sets a positive predictive value of 55%
+#' PPV <- 55/100  # (condition = TRUE) for 55 out of 100 people with (decision = positive)
+#' is_prob(PPV)   # TRUE
 #'
 #' @family probabilities
 #'
@@ -704,13 +694,12 @@ ppod <- 1/2  # default rate of positive decisions
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
+#' \code{\link{is_prob}} verifies probabilities.
 
 PPV <- 1/2  # default of positive predictive value (PPV)
 
 
-## -----------------------------------------------
-## (2) FDR: false detection rate = 1 - PPV
+## (2) FDR: false detection rate = 1 - PPV -------
 
 #' The false detection rate of a decision process or diagnostic procedure.
 #'
@@ -733,8 +722,8 @@ PPV <- 1/2  # default of positive predictive value (PPV)
 #'
 #'   \item Perspective:
 #'   \code{FDR} further classifies
-#'   the subset of \code{\link{dec.pos}} individuals
-#'   by condition (\code{FDR = fa/dec.pos = fa/(hi + fa)}).
+#'   the subset of \code{\link{dec_pos}} individuals
+#'   by condition (\code{FDR = fa/dec_pos = fa/(hi + fa)}).
 #'
 #'
 #'   \item Alternative names:
@@ -756,10 +745,10 @@ PPV <- 1/2  # default of positive predictive value (PPV)
 #'
 #'   \item In terms of frequencies,
 #'   \code{FDR} is the ratio of
-#'   \code{\link{fa}} divided by \code{\link{dec.pos}}
+#'   \code{\link{fa}} divided by \code{\link{dec_pos}}
 #'   (i.e., \code{\link{hi} + \link{fa}}):
 #'
-#'   \code{FDR = fa/dec.pos = fa/(hi + fa)}
+#'   \code{FDR = fa/dec_pos = fa/(hi + fa)}
 #'
 #'
 #'   \item Dependencies:
@@ -775,30 +764,29 @@ PPV <- 1/2  # default of positive predictive value (PPV)
 #'
 #' }
 #'
-#' @references
-#' Consult \href{https://en.wikipedia.org/wiki/Positive_and_negative_predictive_values}{Wikipedia} for additional information.
+#' @examples
+#' FDR <- .45     # sets a false detection rate (FDR) of 45%
+#' FDR <- 45/100  # (condition = FALSE) for 45 out of 100 people with (decision = positive)
+#' is_prob(FDR)   # TRUE
 #'
 #' @family probabilities
 #'
 #' @seealso
-#' \code{\link{comp_FDR}} computes \code{FDR} as the complement of \code{\link{PPV}};
 #' \code{\link{prob}} contains current probability information;
 #' \code{\link{comp_prob}} computes current probability information;
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
+#' \code{\link{freq}} contains current frequency information;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
+#' \code{\link{is_prob}} verifies probabilities.
 #'
-#' @examples
-#' FDR <- .45     # => sets a false discovery rate (FDR) of 45%
-#' FDR <- 45/100  # => (condition = FALSE) for 45 out of 100 people with (decision = positive)
-#' is_prob(FDR)   # => TRUE (as FDR is a probability)
+#' @references
+#' Consult \href{https://en.wikipedia.org/wiki/Positive_and_negative_predictive_values}{Wikipedia} for additional information.
 
-FDR <- 1 - PPV  # default of false discorvery rate (FDR)
+FDR <- (1 - PPV)  # default of false discorvery rate (FDR)
 
 
-## -----------------------------------------------
-## (3) NPV: negative predictive value
+## (3) NPV: negative predictive value ------------
 
 #' The negative predictive value of a decision process or diagnostic procedure.
 #'
@@ -821,14 +809,12 @@ FDR <- 1 - PPV  # default of false discorvery rate (FDR)
 #'
 #'   \item Perspective:
 #'   \code{NPV} further classifies
-#'   the subset of \code{\link{dec.neg}} individuals
-#'   by condition (\code{NPV = cr/dec.neg = cr/(mi + cr)}).
-#'
+#'   the subset of \code{\link{dec_neg}} individuals
+#'   by condition (\code{NPV = cr/dec_neg = cr/(mi + cr)}).
 #'
 #'   \item Alternative names:
 #'   true omission rate
 #'
-#'
 #'   \item Relationships:
 #'
 #'   a. \code{NPV} is the complement of the
@@ -845,10 +831,10 @@ FDR <- 1 - PPV  # default of false discorvery rate (FDR)
 #'
 #'   \item In terms of frequencies,
 #'   \code{NPV} is the ratio of
-#'   \code{\link{cr}} divided by \code{\link{dec.neg}}
+#'   \code{\link{cr}} divided by \code{\link{dec_neg}}
 #'   (i.e., \code{\link{cr} + \link{mi}}):
 #'
-#'   \code{NPV = cr/dec.neg = cr/(cr + mi)}
+#'   \code{NPV = cr/dec_neg = cr/(cr + mi)}
 #'
 #'
 #'   \item Dependencies:
@@ -865,6 +851,11 @@ FDR <- 1 - PPV  # default of false discorvery rate (FDR)
 #'
 #' }
 #'
+#' @examples
+#' NPV <- .95     # sets a negative predictive value of 95%
+#' NPV <- 95/100  # (condition = FALSE) for 95 out of 100 people with (decision = negative)
+#' is_prob(NPV)   # TRUE
+#'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Positive_and_negative_predictive_values}{Wikipedia} for additional information.
 #'
@@ -877,18 +868,12 @@ FDR <- 1 - PPV  # default of false discorvery rate (FDR)
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
-#'
-#' @examples
-#' NPV <- .95     # => sets a negative predictive value of 95%
-#' NPV <- 95/100  # => (condition = FALSE) for 95 out of 100 people with (decision = negative)
-#' is_prob(NPV)   # => TRUE (as NPV is a probability)
+#' \code{\link{is_prob}} verifies probabilities.
 
 NPV <- 1/2  # default of negative predictive value (NPV)
 
 
-## -----------------------------------------------
-## (4) FOR: False omission rate = 1 - NPV
+## (4) FOR: False omission rate = 1 - NPV --------
 
 #' The false omission rate (FOR) of a decision process or diagnostic procedure.
 #'
@@ -909,14 +894,12 @@ NPV <- 1/2  # default of negative predictive value (NPV)
 #'
 #'   \item Perspective:
 #'   \code{FOR} further classifies
-#'   the subset of \code{\link{dec.neg}} individuals
-#'   by condition (\code{FOR = mi/dec.neg = mi/(mi + cr)}).
-#'
+#'   the subset of \code{\link{dec_neg}} individuals
+#'   by condition (\code{FOR = mi/dec_neg = mi/(mi + cr)}).
 #'
 #'   \item Alternative names:
 #'   none?
 #'
-#'
 #'   \item Relationships:
 #'
 #'   a. \code{FOR} is the complement of the
@@ -931,14 +914,12 @@ NPV <- 1/2  # default of negative predictive value (NPV)
 #'
 #'   \code{mirt = p(decision = negative | condition = TRUE)}
 #'
-#'
 #'   \item In terms of frequencies,
 #'   \code{FOR} is the ratio of
-#'   \code{\link{mi}} divided by \code{\link{dec.neg}}
+#'   \code{\link{mi}} divided by \code{\link{dec_neg}}
 #'   (i.e., \code{\link{mi} + \link{cr}}):
 #'
-#'   \code{NPV = mi/dec.neg = mi/(mi + cr)}
-#'
+#'   \code{NPV = mi/dec_neg = mi/(mi + cr)}
 #'
 #'   \item Dependencies:
 #'   \code{FOR} is a feature of a decision process
@@ -952,6 +933,11 @@ NPV <- 1/2  # default of negative predictive value (NPV)
 #'
 #' }
 #'
+#' @examples
+#' FOR <- .05     # sets a false omission rate of 5%
+#' FOR <- 5/100   # (condition = TRUE) for 5 out of 100 people with (decision = negative)
+#' is_prob(FOR)   # TRUE
+#'
 #' @references
 #' Consult \href{https://en.wikipedia.org/wiki/Positive_and_negative_predictive_values}{Wikipedia} for additional information.
 #'
@@ -964,22 +950,168 @@ NPV <- 1/2  # default of negative predictive value (NPV)
 #' \code{\link{num}} contains basic numeric parameters;
 #' \code{\link{init_num}} initializes basic numeric parameters;
 #' \code{\link{comp_freq}} computes current frequency information;
-#' \code{\link{is_prob}} verifies probability inputs.
-#'
-#'
-#' @examples
-#' FOR <- .05     # => sets a false omission rate of 5%
-#' FOR <- 5/100   # => (condition = TRUE) for 5 out of 100 people with (decision = negative)
-#' is_prob(FOR)   # => TRUE (as FOR is a probability)
+#' \code{\link{is_prob}} verifies probabilities.
 
 FOR <- 1 - NPV  # default of false omission rate (FOR)
 
 
-## -----------------------------------------------
-## (+) ToDo:
+## C: Define probabilities by accuracy: ----------
 
-## - Check all documentation
+## (1) Accuracy acc: --------
+
+#' Accuracy (acc) is the probability of a correct decision.
+#'
+#' \code{acc} defines overall accuracy
+#' as the probability of correspondence between a positive decision
+#' and true condition (i.e., the proportion of correct classification
+#' decisions or of \code{\link{dec_cor}} cases).
+#'
+#' Importantly, correct decisions \code{\link{dec_cor}}
+#' are not necessarily positive decisions \code{\link{dec_pos}}.
+#'
+#' Understanding or obtaining the accuracy metric \code{acc}:
+#'
+#' \itemize{
+#'
+#'   \item Definition:
+#'   \code{acc} is the (non-conditional) probability:
+#'
+#'   \code{acc = p(dec_cor) = dec_cor/N}
+#'
+#'   or the base rate (or baseline probability)
+#'   of a decision being correct, but not necessarily positive.
+#'
+#'   \code{acc} values range
+#'   from 0 (no correct decision/prediction)
+#'   to 1 (perfect decision/prediction).
+#'
+#'   \item Computation: \code{acc} can be computed in several ways:
+#'
+#'    (a) from \code{\link{prob}}: \code{acc = (prev x sens) + [(1 - prev) x spec]}
+#'
+#'    (b) from \code{\link{freq}}: \code{acc = dec_cor/N = (hi + cr)/(hi + mi + fa + cr)}
+#'
+#'    (c) as complement of the error rate \code{\link{err}}: \code{acc = 1 - err}
+#'
+#'    When frequencies in \code{\link{freq}} are not rounded, (b) coincides with (a) and (c).
+#'
+#'   \item Perspective:
+#'   \code{acc} classifies a population of \code{\link{N}} individuals
+#'   by accuracy/correspondence (\code{acc = dec_cor/N}).
+#'
+#'   \code{acc} is the "by accuracy" or "by correspondence" counterpart
+#'   to \code{\link{prev}} (which adopts a "by condition" perspective) and
+#'   to \code{\link{ppod}} (which adopts a "by decision" perspective).
+#'
+#'   \item Alternative names:
+#'   base rate of correct decisions,
+#'   non-erroneous cases
+#'
+#'   \item In terms of frequencies,
+#'   \code{acc} is the ratio of
+#'   \code{\link{dec_cor}} (i.e., \code{\link{hi} + \link{cr}})
+#'   divided by \code{\link{N}} (i.e.,
+#'   \code{\link{hi} + \link{mi}} + \code{\link{fa} + \link{cr}}):
+#'
+#'   \code{acc = dec_cor/N = (hi + cr)/(hi + mi + fa + cr)}
+#'
+#'   \item Dependencies:
+#'   \code{acc} is a feature of both the environment (true condition) and
+#'   of the decision process or diagnostic procedure. It reflects the
+#'   correspondence of decisions to conditions.
+#'
+#' }
+#'
+#' See \code{\link{accu}} for other accuracy metrics
+#' and several possible interpretations of accuracy.
+#'
+#' @aliases
+#' accurate correct
+#'
+#' @examples
+#' acc <- .50     # sets a rate of correct decisions of 50%
+#' acc <- 50/100  # (dec_cor) for 50 out of 100 individuals
+#' is_prob(acc)   # TRUE
+#'
+#' @family probabilities
+#' @family metrics
+#'
+#' @seealso
+#' \code{\link{comp_acc}} computes accuracy from probabilities;
+#' \code{\link{accu}} lists all accuracy metrics;
+#' \code{\link{comp_accu_prob}} computes exact accuracy metrics from probabilities;
+#' \code{\link{comp_accu_freq}} computes accuracy metrics from frequencies;
+#' \code{\link{comp_sens}} and \code{\link{comp_PPV}} compute related probabilities;
+#' \code{\link{is_extreme_prob_set}} verifies extreme cases;
+#' \code{\link{comp_complement}} computes a probability's complement;
+#' \code{\link{is_complement}} verifies probability complements;
+#' \code{\link{comp_prob}} computes current probability information;
+#' \code{\link{prob}} contains current probability information;
+#' \code{\link{is_prob}} verifies probabilities.
+#'
+#' @references
+#' Consult \href{https://en.wikipedia.org/wiki/Accuracy_and_precision}{Wikipedia:Accuracy_and_precision} for additional information.
+
+acc <- 1/2  # initialize to random accuracy
+
+
+## (2) Error rate err: --------
+
+#' Error rate (err) as the probability of an incorrect decision.
+#'
+#' \code{err} defines the error rate as the complement of
+#' accuracy \code{\link{acc}} or lack of correspondence
+#' of decisions to conditions.
+#'
+#' Definition:
+#'
+#' \code{err = (1 - \link{acc})}
+#'
+#' When \code{\link{freq}} are not rounded (\code{round = FALSE}) then
+#'
+#' \code{err = \link{dec_err}/\link{N} = (\link{mi} + \link{fa})/\link{N}}
+#'
+#' \code{err} is currently not included in \code{\link{prob}},
+#' but shown in plots.
+#'
+#' See \code{err}'s complement of accuracy \code{\link{acc}}
+#' for computation and
+#' \code{\link{accu}} for current accuracy metrics
+#' and several possible interpretations of accuracy.
+#'
+#' @examples
+#' err <- .50     # sets a rate of incorrect decisions of 50%
+#' err <- 50/100  # (dec_err) for 50 out of 100 individuals
+#' is_prob(err)   # TRUE
+#'
+#' @family probabilities
+#' @family metrics
+#'
+#' @seealso
+#' \code{\link{acc}} provides overall accuracy;
+#' \code{\link{comp_acc}} computes accuracy from probabilities;
+#' \code{\link{accu}} lists current accuracy metrics;
+#' \code{\link{comp_accu_prob}} computes exact accuracy metrics from probabilities;
+#' \code{\link{comp_accu_freq}} computes accuracy metrics from frequencies;
+#' \code{\link{comp_sens}} and \code{\link{comp_PPV}} compute related probabilities;
+#' \code{\link{is_extreme_prob_set}} verifies extreme cases;
+#' \code{\link{comp_complement}} computes a probability's complement;
+#' \code{\link{is_complement}} verifies probability complements;
+#' \code{\link{comp_prob}} computes current probability information;
+#' \code{\link{prob}} contains current probability information;
+#' \code{\link{is_prob}} verifies probabilities.
+
+err <- (1 - acc)  # initialize err to complement of accuracy
+
+## (*) Done: -------------------------------------
+
+## - Add err to prob.  [2018 09 05]
+## - Add acc to prob.  [2018 09 04]
+## - Clean up code.    [2018 08 20]
+
+## (+) ToDo: -------------------------------------
+
+## - Check documentation
 ##   (for correctness and consistency).
 
-## -----------------------------------------------
-## eof.
+## eof. ------------------------------------------
